<?php
/**
 * PHPDevShell is a RAD Framework aimed at developing administrative applications.
 *
 * @package PHPDevShell
 * @link http://www.phpdevshell.org
 * @copyright Copyright (C) 2007 Jason Schoeman, All rights reserved.
 * @license GNU/LGPL, see readme/licensed_under_lgpl or http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 * Copyright notice: See readme/notice
 * By using PHPDevShell you agree to notice and license, if you dont agree to this notice/license you are not allowed to use PHPDevShell.
 */
/**
 * This class contains methods that prints out to the template system, the template system is what the user see when using your application.
 * This means everything that is supposed to echo to the users browser is done with this class.
 * This class resides in the global variable $template and these methods can be called by $template->call_any_method().
 * Stop Here
 * @author Jason Schoeman
 * @deprecated
 * @since 2007/01/03
 */
class template extends PHPDS_dependant
{
	/**
	 * When this variable is assigned, the cronjob will output to his template system if it is enabled in the config.
	 *
	 * @var string
	 */
	public $cron_output;
	/**
	 * Contains active language identifier being used.
	 *
	 * @var string
	 */
	public $active_language;
	//////////////////////////////////// TEMPLATE MODIFY INJECTIONS ///////////////////////////////////////////
	/**
	 * Use this variable to modify the output templates title.
	 *
	 * @var string
	 */
	public $modify_output_title = false;
	/**
	 * Use this variable to modify the output templates active info.
	 *
	 * @var string
	 */
	public $modify_output_active_info = false;
	/**
	 * Use this variable to modify the output templates breadcrumbs.
	 *
	 * @var string
	 */
	public $modify_output_breadcrumbs = false;
	/**
	 * Use this variable to modify the output templates menu.
	 *
	 * @var string
	 */
	public $modify_output_menu = false;
	/**
	 * Use this variable to modify the output templates script.
	 *
	 * @var string
	 */
	public $modify_output_script = false;
	/**
	 * Use this variable to modify the output templates footer.
	 *
	 * @var string
	 */
	public $modify_output_footer = false;
	/**
	 * Contains array with existing registered hook points for active script.
	 *
	 * @var array
	 */
	public $hook_array;
	/**
	 * The hook position id (head, foot, aaa, etc...) that is being required in main script.
	 * This helps the developer split its code to only a specific hook area.
	 *
	 * Example:
	 * <code>
	 * if ($template->hook_request = 'head')
	 * {
	 * 		// Do head code here.
	 * }
	 *
	 * </code>
	 *
	 * @var string
	 */
	public $hook_request;
	/**
	 * Used to remember the last random color.
	 *
	 * @var array
	 */
	private $existing_random_color;
	/**
	 * Contains script HTML data.
	 *
	 * @var string
	 */
	public $HTML = '';
	/**
	 * Contains script HOOK data.
	 *
	 * @var string
	 */
	public $HOOK = '';
	/**
	 * Use to manage the view class.
	 *
	 * @var object
	 */
	public $view;

	////////////////////////////////// END TEMPLATE MODIFY INJECTIONS /////////////////////////////////////////
	/**
	 * Outputs current language identifier being used.
	 *
	 * @author Jason Schoeman
	 */
	public function output_language ($return = false)
	{
		// Check if we should return or print.
		if ($return == false) {
			// Simply output charset.
			print $this->configuration['language'];
		} else {
			return $this->configuration['language'];
		}
	}

	/**
	 * Outputs charset.
	 *
	 * @author Jason Schoeman
	 */
	public function output_charset ($return = false)
	{
		// Check if we should return or print.
		if ($return == false) {
			// Simply output charset.
			print $this->configuration['charset'];
		} else {
			return $this->configuration['charset'];
		}
	}

	/**
	 * Outputs the active scripts title.
	 *
	 * @author Jason Schoeman
	 */
	public function output_title ()
	{
		// Check if output should be modified.
		if ($this->modify_output_title == false) {
			if (isset($this->navigation->navigation[$this->configuration['m']]['menu_name'])) {
				print $this->navigation->navigation[$this->configuration['m']]['menu_name'] . ' - ' . $this->configuration['scripts_name_version'];
			} else {
				print ___('Error!');
			}
		} else {
			print $this->modify_output_title;
		}
	}

	/**
	 * Gets the desired logo and displays it. This method will try its best to deliver a logo, whatever the case.
	 *
	 * @author Jason Schoeman
	 */
	public function output_logo ()
	{
		// First we need to see if we will be using the custom logo.
		if (! empty($this->configuration['custom_logo'])) {
			// Give him his custom logo.
			$logo = sprintf($this->module['logo'], $this->configuration['absolute_url'], $this->configuration['custom_logo'], $this->configuration['scripts_name_version'], $this->configuration['scripts_name_version']);
		} else {
			// Ok so we have no set logo, does the developer want a custom logo?
			if (! empty($this->db->pluginLogo)) {
				// Ok lets get the logo that the user wishes to display.
				$logo = sprintf($this->module['logo'], $this->configuration['absolute_url'], "plugins/{$this->db->pluginLogo}/images/logo.png", $this->configuration['scripts_name_version'], $this->configuration['scripts_name_version']);
			} else {
				// Oops we have no logo, so lets just default to the orginal PHPDevShell logo.
				$logo = sprintf($this->module['logo'], $this->configuration['absolute_url'], "plugins/PHPDevShell/images/logo.png", $this->configuration['scripts_name_version'], $this->configuration['scripts_name_version']);
			}
		}
		// Ok return the logo.
		print $logo;
	}

	/**
	 * Returns "users version number" and some other detail to the template system. Intended to be used by the engine.
	 *
	 * @author Jason Schoeman
	 */
	public function output_active_info ()
	{
		// Check if output should be modified.
		if ($this->modify_output_active_info == false) {
			if ($this->user->isLoggedIn()) {
				$login_information = sprintf(___('<a href="%s">Log Out, %s</a>'), $this->navigation->buildURL($this->configuration['loginandout'], 'logout=1'), $this->configuration['user_display_name']);
				$logged_in_icon = 'logged_in_icon';
			} else {
				$login_information = sprintf(___('<a href="%s">Log in, %s</a>'), $this->navigation->buildURL($this->configuration['loginandout']), $this->configuration['user_display_name']);
				$logged_in_icon = 'logged_out_icon';
			}
			// Set active group.
			$active_group = sprintf(___('%s Group'), $this->configuration['user_group_name']);
			// Set active role.
			$active_role = sprintf(___('%s Role'), $this->configuration['user_role_name']);
			// Glue active area.
			$active_area = sprintf($this->module['login'], $logged_in_icon, $this->configuration['scripts_name_version'], $this->core->formatTimeDate($this->configuration['time']), $login_information, $active_group, $active_role);
			// Output active info.
			print $active_area;
		} else {
			print $this->modify_output_active_info;
		}
	}

	/**
	 * Returns "breadcrumbs" to the template system. Intended to be used by the engine.
	 *
	 * @author Jason Schoeman
	 */
	public function output_breadcrumbs ()
	{
		// Check if output should be modified.
		if ($this->modify_output_breadcrumbs == false) {
			print $this->navigation->generate_history_tree();
		} else {
			print $this->modify_output_breadcrumbs;
		}
	}

	/**
	 * Returns "menus" to the template system. Intended to be used by the engine.
	 *
	 * @author Jason Schoeman
	 */
	public function output_menu ()
	{
		// Check if output should be modified.
		if ($this->modify_output_menu == false) {
			print $this->navigation->createMenuStructure();
		} else {
			print $this->modify_output_menu;
		}
	}

	/**
	 * This function support output_script by looking deeper into menu structure to find last linked menu item that is not linked to another.
	 *
	 * @deprecated
	 * @param integer $extended_menu_id
	 * @return integer
	 */
	public function extend_menu_loop ($extended_menu_id)
	{
		return $this->extendMenuLoop($extended_menu_id);
	}

	/**
	 * Returns "output script" to the template system. Intended to be used by the engine.
	 *
	 * @author Jason Schoeman
	 */
	public function output_script ()
	{
		////////////////////////////////////////////////////////////////////////////////////////
		// Check if output should be modified.
		if ($this->modify_output_script == false) {
			// Start SQL transactions.
			$this->db->start_transaction();
			// Content buffer.
			ob_start();
			// Are we in demo mode?
			if ($this->configuration['demo_mode'] == true) {
				if ($this->configuration['user_role'] != $this->configuration['root_role']) {
					// Show demo mode message for end user.
					$this->notice(sprintf(___('%s is currently in a demo mode state, no actual database transactions will occur.'), $this->configuration['scripts_name_version']));
				} else {
					// Show demo mode message for root user.
					$this->notice(sprintf(___('%s is currently in a demo mode state, only Root users are able to save database transactions.'), $this->configuration['scripts_name_version']));
				}
			}
			// Load script to buffer.
			if (! empty($this->navigation->navigation[$this->configuration['m']]['menu_id'])) {
				// We need to assign active menu_id.
				$menu_id = $this->configuration['m'];
				// Determine correct menu action.
				switch ($this->navigation->navigation[$this->configuration['m']]['menu_type']) {
					// Plugin File.
					case 1:
						// Do case.
						$menu_case = 1;
						break;
					// Link.
					case 2:
						break;
					// Jump.
					case 3:
						break;
					// External File.
					case 4:
						// Do case.
						$menu_case = 4;
						break;
					// HTTP URL.
					case 5:
						// Do case.
						$menu_case = 5;
						break;
					// Placeholder.
					case 6:
						break;
					// iFrame.
					case 7:
						// Do case.
						$menu_case = 7;
						break;
					// Cronjob.
					case 8:
						// Do case.
						$menu_case = 8;
						break;
					default:
						// Do case.
						$menu_case = 1;
						break;
				}
				///////////////////////////////////
				// Do further checking on links. //
				///////////////////////////////////
				if (empty($menu_case)) {
					// So we have some kind of link, we now need to see what kind of link we have.
					// Get menu extended data.
					$extend = $this->navigation->navigation[$menu_id]['extend'];
					// Get menu type.
					if (!empty($this->navigation->navigation[$extend]['menu_type'])) {
						$linked_menu_type = $this->navigation->navigation[$extend]['menu_type'];
					} else {
						$this->stopScript = sprintf(___('I had a problem extending menu item %s, it does not seem to exist.'), $extend);
					}
					// We now have the linked menu type and can now work accordingly.
					// Determine correct menu action.
					switch ($linked_menu_type) {
						// Plugin File.
						case 1:
							// Do case.
							$menu_case = 1;
							// We need to assign active menu_id.
							$menu_id = $extend;
							break;
						// Link.
						case 2:
							// Do case.
							$menu_case = 2;
							// We need to assign active menu_id.
							$this->extend_menu_loop($this->navigation->navigation[$extend]['extend']);
							$menu_id = $this->extended_menu_id;
							break;
						// Jump.
						case 3:
							// Do case.
							$menu_case = 2;
							// We need to assign active menu_id.
							$this->extend_menu_loop($this->navigation->navigation[$extend]['extend']);
							$menu_id = $this->extended_menu_id;
							break;
						// External File.
						case 4:
							// Do case.
							$menu_case = 4;
							// We need to assign active menu_id.
							$menu_id = $extend;
							break;
						// HTTP URL.
						case 5:
							// Do case.
							$menu_case = 5;
							// We need to assign active menu_id.
							$menu_id = $extend;
							break;
						// Placeholder.
						case 6:
							// Do case.
							$menu_case = 2;
							// We need to assign active menu_id.
							$this->extend_menu_loop($this->navigation->navigation[$extend]['extend']);
							$menu_id = $this->extended_menu_id;
							break;
						// iFrame.
						case 7:
							// Do case.
							$menu_case = 7;
							// We need to assign active menu_id.
							$menu_id = $extend;
							break;
						// Cronjob.
						case 8:
							// Do case.
							$menu_case = 8;
							// We need to assign active menu_id.
							$menu_id = $extend;
							break;
						default:
							// Do case.
							$menu_case = 1;
							// We need to assign active menu_id.
							$menu_id = $extend;
							break;
					}
				}
				// Execute repeated menu cases.
				switch ($menu_case) {
					// Plugin Script.
					case 1:
						// Set plugin folder.
						$plugin_folder = $this->navigation->navigation[$menu_id]['plugin_folder'];
						// Set active script directory.
						$active_dir = $plugin_folder . $this->navigation->navigation[$menu_id]['menu_link'];
						// Require script.
						$this->view = new view();
						if (!$this->core->loadFile($active_dir)) {
							$this->stopScript = sprintf(___('The script could not be found, I tried to execute filename : %s'), $active_dir);
						}
						break;
					// Link, Jump, Placeholder.
					case 2:
						// Is this an empty menu item?
						if (empty($menu_id)) {
							// Lets take user to the front page as last option.
							// Get correct frontpage id.
							($this->user->isLoggedIn()) ? $menu_id = $this->configuration['front_page_id_in'] : $menu_id = $this->configuration['front_page_id'];
						}
						// Set plugin folder.
						$plugin_folder = $this->navigation->navigation[$menu_id]['plugin_folder'];
						// Set active script directory.
						$active_dir = $plugin_folder . $this->navigation->navigation[$menu_id]['menu_link'];
						// Load template engine.
						$this->view = new view();
						// Require script.
						if (!$this->core->loadFile($active_dir)) {
							$this->stopScript = sprintf(___('The script could not be found, I tried to execute filename : %s'), $active_dir);
						}
						break;
					// External File.
					case 4:
						// Load template engine.
						$this->view = new view();
						// Require external file.
						if (!$this->core->loadFile($this->navigation->navigation[$menu_id]['menu_link'])) {
							$this->stopScript = sprintf(___('The script could not be found, I tried to execute filename : %s'), $this->navigation->navigation[$menu_id]['menu_link']);
						}
						break;
					// HTTP URL.
					case 5:
						// Redirect to external http url.
						$this->ok(sprintf(___('You are now being redirected to an external url, %s'), $this->navigation->navigation[$menu_id]['menu_link']), false, false);
						$this->navigation->redirect($this->navigation->navigation[$menu_id]['menu_link']);
						break;
					// iFrame.
					case 7:
						// Clean up height.
						$height = preg_replace('/px/i', '', $this->navigation->navigation[$menu_id]['extend']);
						// Create Iframe.
						$this->HTML = sprintf($this->module['iframe'], $this->navigation->navigation[$menu_id]['menu_link'], $height);
						break;
					// Cronjob.
					case 8:
						// Set plugin folder.
						$plugin_folder = $this->navigation->navigation[$menu_id]['plugin_folder'];
						// Set active script directory.
						$active_dir = $plugin_folder . $this->navigation->navigation[$menu_id]['menu_link'];
						// Load template engine.
						$this->view = new view();
						// Require script.
						if (!$this->core->loadFile($active_dir)) {
							$this->stopScript = sprintf(___('The script could not be found, I tried to execute filename : %s'), $active_dir);
						} else {
							$time_now = time();
							// Update last execution.
							$this->db->new_query("
								UPDATE
									_db_core_cron t1
								SET
									t1.last_execution = '$time_now'
								WHERE
									t1.menu_id = '{$menu_id}'
							");
							// Always log manual touched cronjobs.
							$this->ok(sprintf(___('Cronjob %s executed manually.'), $this->navigation->navigation[$menu_id]['menu_name']));
						}
						break;
				}
				// This is used for debugging scripts.
				// It will always show if $template->debugStr is set.
				($this->debugStr) ? $this->notice($this->debugStr) : null;
				// Print HEREDOC HTML.
				if (! empty($this->HTML)) print $this->HTML;
			} else {
				$this->stopScript = ___('SECURITY ALERT, There seems to be a security limitation, you are not allowed to run this script or the script could not be found. Make sure your session did not expire, you might be logged out.');
			}
			if (isset($this->stopScript)) {
				// Roll back current transaction.
				mysql_query("ROLLBACK", $this->db->connection);
				// Clear buffer and turn off output buffering.
				ob_end_clean();
				// Output critical message while logging it.
				$security_output = $this->warning($this->stopScript, true);
				// Check if user is logged in.
				if (! $this->user->isLoggedIn() && empty($this->skipLogin)) {
					// Set heading information.
					$security_output .= $this->heading(___('Log In Page'), true);
					$security_output .= $this->info(___('Please fill in your Username and Password. Letters are case sensitive.'), true);
					// Display login template.
					$security_output .= $this->login_template($this->navigation->buildURL(3682403894), $_SERVER['REQUEST_URI'], true);
				}
				print $security_output;
			} else {
				// Print out buffer.
				ob_end_flush();
			}
			// End database transactions.
			$this->db->end_transaction();
		} else {
			print $this->modify_output_script;
		}
	}

	/**
	 * The exact location where hook should be applied.
	 *
	 * @param integer $hook_point_id The unique id given to a hook.
	 */
	public function hook ($hook_point_id)
	{
		///////////////////////////////////////////////////////////////////////////////
		// Check if we should even continue.
		if (empty($this->hook_array) || $this->hook_array == 'empty') return false;
		// Assign hook array for this loop.
		if (empty($this->hook_array[$this->configuration['m']][$hook_point_id])) {
			return false;
		} else {
			$hook_array_foreach = $this->hook_array[$this->configuration['m']][$hook_point_id];
		}
		// Now lets include hook files.
		if (! empty($hook_array_foreach)) {
			// Clear previous results.
			$results = false;
			// Loop the array and see what needs be included.
			foreach ($hook_array_foreach as $hook_array) {
				// Set variables.
				$plugin = $hook_array['plugin'];
				$hook_name = $hook_array['hook_name'];
				// Create hook file path.
				$include_hook_file = 'plugins/' . $plugin . '/hooks/' . $hook_name . '.hook.php';

				// But does the file exist?
				if (file_exists($include_hook_file)) {
					// Lets give developer an idea of what hook position we are in.
					$this->hook_request = $hook_point_id;
					// Execute hook.
					$this->core->loadFile ($include_hook_file, false, true, false);
					// Collect results for output and returning;
					if (! empty($this->HOOK)) {
						$results .= $this->HOOK;
						$this->HOOK = '';
					}
				}
			}
		}
		// Return hook results.
		return $results;
	}

	/**
	 * Returns the last footer string to the template system. Intended to be used by the engine.
	 *
	 * @author Jason Schoeman
	 */
	public function output_footer ()
	{
		// Create printable template url.
		if (!empty($this->configuration['printable_template'])) {
			if (empty($_SESSION['fast']) || $_SESSION['fast'] == 'off') {
				$printable = "<a href=\"{$this->navigation->buildURL(false, 'fast=on')}\">" . ___('[Printable|Faster Template On]') . "</a>";
			} else {
				$printable = "<a href=\"{$this->navigation->buildURL(false, 'fast=off')}\">" . ___('[Printable|Faster Template Off]') . "</a>";
			}
		} else {
			$printable = '';
		}
		// Create HTML.
		$html = sprintf($this->module['footer'], $this->configuration['scripts_name_version'], $this->configuration['footer_notes'], $printable);
		// Check if output should be modified.
		if ($this->modify_output_footer == false) {
			print $html;
		} else {
			print $this->modify_output_footer;
		}
	}

	/**
	 * Will pick image or text icon depending on print or fast mode.
	 *
	 * @param string The url of the image icon to display.
	 * @param string The alternative text if in fast mode.
	 * @author Jason Schoeman
	 */
	public function iconize ($img,$text)
	{
		if (empty($_SESSION['fast'])) {
			return $img;
		} else {
			return $text;
		}
	}

	/**
	 * This creates an the [i] when over with mouse a popup with a message appears, this can be placed anywhere. Intended to be used by the developer.
	 *
	 * @param string The message to diplay when mouse goes over the [i].
	 * @param boolean Sets to print out confirm link instead of return.
	 * @author Jason Schoeman
	 */
	public function info_mark ($info_mark, $print = false)
	{
		// This is yet another IE Fix !
		$info_mark_clean = preg_replace('/"/', '', $info_mark);
		$info = sprintf($this->module['info_mark'], $this->lang['help_icon'], $info_mark_clean);
		if ($print == false) {
			return $info;
		} else {
			print $info;
		}
	}

	/**
	 * Print out any message given to it (instead of return). Intended to be used by the developer.
	 *
	 * @param string Message to print out.
	 * @author Jason Schoeman
	 */
	public function out ($variable)
	{
		print $variable;
	}

	/**
	 * Does the alternating colors of rows when there is more then 1 result. Intended to be used by the developer.
	 *
	 * @param mixed The value of the previous row.
	 * @author Jason Schoeman
	 */
	public function alt_color ($alt)
	{
		if ($alt == 'alt1') {
			return 'alt2';
		} else {
			return 'alt1';
		}
	}

	/**
	 * Creates a random soft color by group. Intended to be used by the developer.
	 *
	 * @param int Unique id of the group which needs a color.
	 * @author Jason Schoeman
	 */
	public function random_color ($id)
	{
		$r = rand(200, 255);
		$g = rand(200, 255);
		$b = rand(200, 255);
		$color = '#' . dechex($r) . dechex($g) . dechex($b);
		// Define.
		$this->existing_random_color[0] = false;
		if (is_array($this->existing_random_color)) {
			if (! key_exists($id, $this->existing_random_color)) {
				$this->existing_random_color[$id] = $color;
				return $this->existing_random_color[$id];
			} else {
				return $this->existing_random_color[$id];
			}
		} else {
			$this->existing_random_color[$id] = $color;
			return $this->existing_random_color[$id];
		}
	}

	/**
	 * Outputs data to the cron template if cron debug is enabled in the configuration.
	 *
	 * @author Jason Schoeman
	 */
	public function template_cron_output ()
	{
		print $this->cron_output;
	}

	/**
	 * Output "no results found" if no results are found in a paging script.
	 *
	 * @param string $RESULTS
	 * @param integer $colspan
	 * @since 2007/04/16
	 */
	public function result ($RESULT, $colspan = 0)
	{
		if (! empty($RESULT)) {
			return $RESULT;
		} else {
			return sprintf($this->module['result'], $colspan, ___('No results found!'));
		}
	}

	/**
	 * Will load template icons and assign to lang array.
	 *
	 */
	public function load_icons ()
	{
		// Create preferred template dir.
		$template_dir = 'themes/' . $this->configuration['template_folder'];
		// Check if we have a icons file.
		if (!$this->core->loadFile ($template_dir . '/icons.php')) {
			// If all else fail, try default template icon file.
			$this->core->loadFile ('themes/cloud/icons.php');
		}
	}

	/**
	 * Get and return the supposed to run template.
	 *
	 * @return string if not found, return default.
	 * @author Jason Schoeman
	 */
	public function get_template ()
	{
		// Assign sessions for fast template.
		(!empty($_GET['fast'])) ? $fast = $_GET['fast'] : $fast = false;
		if ($fast == 'on') {
			$_SESSION['fast'] = 'on';
		} else if ($fast == 'off') {
			$_SESSION['fast'] = false;
		}
		// Do global check to see if we need to load printable template.
		if (!empty($_SESSION['fast'])) {
			$settings['default_template'] = $this->configuration['printable_template'];
		} else {
			// Check if the menu has a defined template.
			if (! empty($this->navigation->navigation[$this->configuration['m']]['template_folder'])) {
				$settings['default_template'] = $this->navigation->navigation[$this->configuration['m']]['template_folder'];
			} else {
				// If not check if the gui system settings was set with a default template.
				$settings['default_template'] = $this->configuration['default_template'];
			}
		}
		// Return the complete template.
		return $settings['default_template'];
	}

	/**
	 * Loads the username & password html template form.
	 *
	 * @deprecated
	 * @param string $goto
	 * @param integer $redirect
	 * @param boolean $return
	 */
	public function login_emplate ($goto, $redirect = false, $return = false)
	{
		$settings = $this->db->essentialSettings;
		if ($redirect != false) {
			$redirect_page = '<input type="hidden" name="redirect" value="' . $redirect . '">';
		} else {
			$redirect_page = false;
		}
		if (! $this->user->isLoggedIn()) {
			// Check if not registered link should appear.
			if ((boolean) $settings['allow_registration'] == true) {
				// Check if we have a custom registration page.
				(! empty($settings['registration_page'])) ? $registration = $this->navigation->buildURL($settings['registration_page']) : $registration = $this->navigation->buildURL(3727066128);
				// Create generic button for registration.
				$not_registered_yet = $this->navigation->generic_button(___('Not registered yet?'), $registration);
			} else {
				$not_registered_yet = false;
			}
			// Create lost password link.
			$lost_password = $this->navigation->generic_button(___('Lost Password?'), $this->navigation->buildURL(1901799184));
			// Create login button.
			$login_button = '<input tabindex="4" type="submit" value="' . ___('Log In') . '" name="login" class="button">';
			// Create the "remember me" checkbox, if needed
			if (!empty($settings['allow_remember'])){
				$remember = sprintf($this->module['remember_checkbox'], ___('Remember Me?'), $this->tip(___('Select this to have your login remembered after you close your browser. Do not use on public computers.')));
			} else {
				$remember = '';
			}
			// Create HTML login field.
			$HTML = sprintf($this->module['login_form'], $goto, ___('Username or Email'), '', $this->tip(___('Enter your username or email address here.')), ___('Password'), '', $this->tip(___('Enter your password here.')), $redirect_page, $login_button, $lost_password, $not_registered_yet, $this->security->postValidation(), $remember);
			if ($return == false) {
				print $HTML;
			} else {
				return $HTML;
			}
		}
	}

	/**
	 * Acquire script identification image or logo.
	 *
	 * @deprecated
	 * @param string $menu_link
	 * @param string $active_plugin
	 */
	public function script_logo ($menu_link, $active_plugin, $alias = null)
	{
		return $this->scriptLogo($menu_link, $active_plugin, $alias);
	}

	/**
	 * Loads the default or custom template (tpl) file and prints it out.
	 * Enter the template file for appropriate script here.
	 *
	 * @param string The name of the template to be loaded
	 * @param string If another plugin is to be used in the directory.
	 */
	public function show ($load_template=false, $plugin=false)
	{
		$this->view->show($load_template, $plugin);
	}

	/**
	 * Loads the default or custom template (tpl) file and prints it out.
	 * Enter the template file for appropriate script here.
	 *
	 * @param string The name of the template to be loaded
	 * @param string If another plugin is to be used in the directory.
	 */
	public function display ($load_template=false, $plugin=false)
	{
		$this->view->show($load_template, $plugin);
	}

	/**
	 * Sets Smarty variables to be passed to it.
	 * Alias of assign.
	 *
	 * @param mixed $var
	 * @param mixed $value
	 */
	public function set ($var, $value)
	{
		$this->view->assign($var, $value);
	}

	/**
	 * Sets Smarty variables to be passed to it.
	 * Alias of assign.
	 *
	 * @param mixed $var
	 * @param mixed $value
	 */
	public function assign ($var, $value)
	{
		$this->view->assign($var, $value);
	}

	/**
	 * Loads the default or custom template (tpl) file and returns results.
	 * Enter the template file for appropriate script here.
	 *
	 * @param string The name of the template to be loaded
	 * @param string If another plugin is to be used in the directory.
	 */
	public function dofetch ($var, $value)
	{
		return $this->view->dofetch($var, $value);
	}

	/**
	 * Loads the default or custom template (tpl) file and returns results.
	 * Enter the template file for appropriate script here.
	 *
	 * @param string The name of the template to be loaded
	 * @param string If another plugin is to be used in the directory.
	 */
	public function fetch ($var, $value)
	{
		return $this->view->dofetch($var, $value);
	}

	/**
	 * Convert all HTML entities to their applicable characters.
	 *
	 * @param string $string_to_decode
	 * @return string
	 */
	public function html_entity_decode ($string_to_decode)
	{
		// Decode characters.
		return $this->htmlEntityDecode($string_to_decode);
	}
}
/**
 * Creates a language tooltip string and prints it out to the template.
 *
 * @param string $info_mark
 */
function _i ($info_mark)
{
	global $template;
	$template->tip(_($info_mark), true);
}
/**
 * Creates a language tooltip string inside a text domain and prints it out to the template.
 *
 * @param string $info_mark
 */
function __i ($info_mark, $domain)
{
	global $template;
	$template->tip(dgettext($domain,$info_mark), true);
}
?>
