<?php

/**
 * PHPDevShell is a RAD Framework aimed at developing administrative applications.
 *
 * @package PHPDevShell
 * @link http://www.phpdevshell.org
 * @copyright Copyright (C) 2007 Jason Schoeman, All rights reserved.
 * @license GNU/LGPL, see readme/licensed_under_lgpl or http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 *
 * Copyright notice: See readme/notice
 * By using PHPDevShell you agree to notice and license, if you dont agree to this notice/license you are not allowed to use PHPDevShell.
 */

/**
 * Controller Class: Users that are listed in pending queue for approval.
 * @author Jason Schoeman
 * @return string
 */
class UserAdminPending extends PHPDS_controller
{

	/**
	 * Execute Controller
	 * @author Jason Schoeman
	 */
	public function execute()
	{
		// Heading.
		$this->template->heading(_('User Registration Pending'));
		// Header information
		$this->template->info(_('List, approve, ban and manage all new registration of users awaiting confirmation or approval, it also adds the ability to delete and edit users.'));

		// Get default verified role and group.
		$settings = $this->db->getSettings(array('move_verified_group', 'move_verified_role', 'banned_role'));
		// Load pending support class.
		$user_pending = $this->factory('userPending');
		$user_pending->settings = $settings;
		// Get default group and role names.
		$default_role_name = $this->db->invokeQuery('PHPDS_defaultRoleName', $settings['move_verified_role']);
		$default_group_name = $this->db->invokeQuery('PHPDS_defaultGroupName', $settings['move_verified_group']);
		// Check if this user can move default registrations.
		($this->user->belongsToGroup(false, $settings['move_verified_group'])) ? $can_move_default = true : $can_move_default = false;
		// Single user action needs to be performed.
		// approve
		if (!empty($this->security->get['au'])) {
			$user_pending->pendingAction($this->security->get['au'], 'au');
		} // approve & email
		else if (!empty($this->security->get['aue'])) {
			$user_pending->pendingAction($this->security->get['aue'], 'aue');
		} // ban user
		else if (!empty($this->security->get['bu'])) {
			$user_pending->pendingAction($this->security->get['bu'], 'bu');
		} // delete user
		else if (!empty($this->security->get['du'])) {
			$user_pending->pendingAction($this->security->get['du'], 'du');
		}
		// Do we have a post situation to do mass action on users?
		if (!empty($this->security->post)) {
			// Define.
			if (!empty($this->security->post['user_id_array'])) {
				$user_id_array = $this->security->post['user_id_array'];
			} else {
				$user_id_array = 0;
			}
			// Start checking post type.
			// approve
			if (!empty($this->security->post['au'])) {
				$action = 'au';
			} // approve & email
			else if (!empty($this->security->post['aue'])) {
				$action = 'aue';
			} // ban user
			else if (!empty($this->security->post['bu'])) {
				$action = 'bu';
			} // delete user
			else if (!empty($this->security->post['du'])) {
				$action = 'du';
			}
			// Do a loop and see what we have to cook.
			if (!empty($user_id_array)) {
				// Start looping and doing actions.
				foreach ($user_id_array as $user_id__) {
					$user_pending->pendingAction($user_id__, $action);
				}
			}
		}
		$RESULTS = $this->db->invokeQuery('PHPDS_readPending', $settings['move_verified_role'], $settings['move_verified_group']);

		// Load views.
		$view = $this->factory('views');

		// Set Array.
		$view->set('pagination', $RESULTS['pagination']);
		$view->set('searchForm', $RESULTS['searchForm']);
		$view->set('th', $RESULTS['th']);
		$view->set('RESULTS', $RESULTS['list']);

		// Set Buttons.
		$view->set('approve_users', _('Approve Users'));
		$view->set('approve_users_email_notification', _('Approve Users & Email Notification'));
		$view->set('ban_users', _('Ban Users'));
		$view->set('delete_users', _('Delete Users'));

		// Set Values.
		$view->set('self_url', $this->navigation->selfUrl());
		$view->set('post_validation', $this->security->postValidation());
		$view->set('confirm_bu', $this->core->confirmLink(sprintf('Are you sure you want to BAN all users on this page?')));
		$view->set('confirm_du', $this->core->confirmLink(sprintf('Are you sure you want to DELETE all users on this page?')));

		// Output Template.
		$view->show();
	}
}

return 'UserAdminPending';