<?php

/**
 * PHPDevShell is a RAD Framework aimed at developing administrative applications.
 *
 * @package PHPDevShell
 * @link http://www.phpdevshell.org
 * @copyright Copyright (C) 2007 Jason Schoeman, All rights reserved.
 * @license GNU/LGPL, see readme/licensed_under_lgpl or http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 *
 * Copyright notice: See readme/notice
 * By using PHPDevShell you agree to notice and license, if you dont agree to this notice/license you are not allowed to use PHPDevShell.
 */

/**
 * Menu Stucture - Read structure.
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 */
class PHPDS_readStructureQuery extends PHPDS_query
{
	protected $sql = "
		SELECT
			t1.menu_id, t1.parent_menu_id
		FROM
			_db_core_menu_items t1
		ORDER BY
			t1.rank
		ASC
    ";
}

/**
 * Menu Stucture - Delete structure.
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 */
class PHPDS_deleteStructureQuery extends PHPDS_query
{
	protected $sql = "
		DELETE FROM
			_db_core_menu_structure
    ";
}

/**
 * Menu Stucture - Reset structure pointer.
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 */
class PHPDS_resetStructureQuery extends PHPDS_query
{
	protected $sql = "
		ALTER TABLE
			_db_core_menu_structure
		AUTO_INCREMENT = 0;
    ";
}

/**
 * Menu Stucture - Write new structure.
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 */
class PHPDS_writeStructureQuery extends PHPDS_query
{
	protected $sql = "
		INSERT INTO
			_db_core_menu_structure (id, menu_id, is_parent, type)
		VALUES
			%s
    ";
}

/**
 * Menu Stucture - Delete Menus.
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 */
class PHPDS_deleteMenusQuery extends PHPDS_query
{
	protected $sql = "
		DELETE FROM
			_db_core_menu_items
		WHERE
			menu_id
		%s
    ";
}

/**
 * Menu Stucture - Delete menu structure.
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 */
class PHPDS_deleteMenuStructureQuery extends PHPDS_query
{
	protected $sql = "
		DELETE FROM
			_db_core_menu_structure
		WHERE
			menu_id
		%s
    ";
}

/**
 * Menu Stucture - Delete role permissions.
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 */
class PHPDS_deleteRolePermissionsQuery extends PHPDS_query
{
	protected $sql = "
		DELETE FROM
			_db_core_user_role_permissions
		WHERE
			menu_id
		%s
    ";
}

/**
 * Menu Stucture - Delete filters.
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 */
class PHPDS_deleteFiltersQuery extends PHPDS_query
{
	protected $sql = "
		DELETE FROM
			_db_core_filter
		WHERE
			menu_id
		%s
    ";
}

/**
 * Menu Stucture - Delete crons.
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 */
class PHPDS_deleteCronsQuery extends PHPDS_query
{
	protected $sql = "
		DELETE FROM
			_db_core_cron
		WHERE
			menu_id
		%s
    ";
}

/**
 * Menu Stucture - Delete one or many menus.
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 */
class PHPDS_deleteMenuQuery extends PHPDS_query
{
	protected $sql = "
		SELECT
			menu_id
		FROM
			_db_core_menu_items
		WHERE
			plugin = '%s'
    ";

	/**
	 * Initiate invoke.
	 *
	 * @return boolean
	 */
	public function invoke ($parameters)
	{
		$db = $this->db;

		list($menu_id, $plugin, $delete_critical_only) = $parameters;
		// Define.
		$db_condition = '';
		// Check if plugin item should be deleted.
		if ($plugin != false && $menu_id == false) {
			$menu_id_db = parent::invoke(array($plugin));

			foreach ($menu_id_db as $menu_id_array) {
				$db_condition .= "'{$menu_id_array['menu_id']}',";
			}
			// Check if there is any condition.
			if (!empty($db_condition)) {
				// Correct for database condition.
				$db_condition = rtrim($db_condition, ",");
				// Complete condition.
				$condition = " IN ($db_condition)";
			}
		} // The user may want to give an array of items to be deleted.
		else if (is_array($menu_id)) {
			foreach ($menu_id as $item_to_delete) {
				// Check if item needs to be converted to menu item.
				$db_condition .= "'$item_to_delete',";
			}
			// Check if there is any condition.
			if (!empty($db_condition)) {
				// Correct for database condition.
				$db_condition = rtrim($db_condition, ",");
				// Complete condition.
				$condition = " IN ($db_condition)";
			}
		} else {
			// Complete condition.
			$condition = " = '$menu_id'";
		}
		// Only execute when not empty.
		if (!empty($condition)) {
			// Delete Menu Items.
			$db->invokeQuery('PHPDS_deleteMenusQuery', $condition);

			// Delete Menu Structure.
			$db->invokeQuery('PHPDS_deleteMenuStructureQuery', $condition);

			// Continue deleting?
			if ($delete_critical_only == false) {
				// Delete Menu Permissions.
				$db->invokeQuery('PHPDS_deleteRolePermissionsQuery', $condition);
				
				// Delete all filters that belongs to this menu item.
				$db->invokeQuery('PHPDS_deleteFiltersQuery', $condition);
				
				// Delete all cron items connected to this menu.
				$db->invokeQuery('PHPDS_deleteCronsQuery', $condition);
			}
			return true;
		}
	}
}

/**
 * Menu Stucture - Write menu item.
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 */
class PHPDS_writeMenuQuery extends PHPDS_query
{
	protected $sql = "
		REPLACE INTO
			_db_core_menu_items (menu_id, parent_menu_id, menu_name, menu_link, plugin, menu_type, extend, new_window, rank, hide, template_id, alias, layout)
		VALUES
			('%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s')
    ";
}

/**
 * Menu Stucture - Get plugin name from menu id.
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 */
class PHPDS_readPluginFromMenuIdQuery extends PHPDS_query
{
	protected $sql = "
		SELECT
			plugin
		FROM
			_db_core_menu_items
		WHERE
			menu_id = '%s'
    ";

	protected $singleValue = true;
}

/**
 * Menu Stucture - Get plugin name from menu id.
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 */
class PHPDS_readMenuIdFromMenuLinkQuery extends PHPDS_query
{
	protected $sql = "
		SELECT
			menu_id
		FROM
			_db_core_menu_items
		WHERE
			menu_link = '%s'
    ";

	protected $singleValue = true;
}


